(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     83127,       2512]
NotebookOptionsPosition[     80342,       2427]
NotebookOutlinePosition[     80995,       2450]
CellTagsIndexPosition[     80952,       2447]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
 "II. Dynamics\n",
 StyleBox["Quadrotor\n", "Subtitle"],
 StyleBox["Attitude\n", "Subsubtitle"],
 StyleBox["The attitude is described by three Euler angles. We define general \
rotation matrices around the x--, y--, and z--axis:", "Text",
  FontFamily->"Arial",
  FontSize->12,
  FontWeight->"Plain"]
}], "Title",
 CellChangeTimes->{{3.493463566846859*^9, 3.4934636710868216`*^9}, {
  3.4934637066478553`*^9, 3.493463741263835*^9}, {3.493463886072118*^9, 
  3.4934638943745923`*^9}, {3.4934639727910776`*^9, 3.4934640570738983`*^9}, {
  3.4934640930879583`*^9, 3.493464094464037*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["R", "x"], "[", "val_", "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"0", ",", " ", 
      RowBox[{"Cos", "[", "val", "]"}], ",", " ", 
      RowBox[{"-", 
       RowBox[{"Sin", "[", "val", "]"}]}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"0", ",", " ", 
      RowBox[{"Sin", "[", "val", "]"}], ",", " ", 
      RowBox[{"Cos", "[", "val", "]"}]}], "}"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["R", "y"], "[", "val_", "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Cos", "[", "val", "]"}], ",", " ", "0", ",", " ", 
      RowBox[{"Sin", "[", "val", "]"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"0", ",", " ", "1", ",", " ", "0"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sin", "[", "val", "]"}]}], ",", " ", "0", ",", " ", 
      RowBox[{"Cos", "[", "val", "]"}]}], "}"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["R", "z"], "[", "val_", "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Cos", "[", "val", "]"}], ",", " ", 
      RowBox[{"-", 
       RowBox[{"Sin", "[", "val", "]"}]}], ",", " ", "0"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Sin", "[", "val", "]"}], ",", " ", 
      RowBox[{"Cos", "[", "val", "]"}], ",", " ", "0"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"0", ",", " ", "0", ",", " ", "1"}], "}"}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.493464080857259*^9, 3.4934641140971603`*^9}, {
  3.4934641586497083`*^9, 3.4934641788728647`*^9}, {3.4934642097776327`*^9, 
  3.493464234537049*^9}, {3.493464270594111*^9, 3.4934644056588364`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Rotational motion\n",
  FontWeight->"Bold"],
 "The Euler angle rates are measured in their respective coordinate systems. \
The vehicle's control inputs are the rates in the vehicle's coordinate system \
{V}. The transformation is done using the Euler ",
 Cell[BoxData[
  FormBox[
   RowBox[{"angles", ":"}], TraditionalForm]], "None"]
}], "Subsubtitle",
 CellChangeTimes->{{3.493464489694643*^9, 3.4934645147670765`*^9}, {
  3.4934645894953513`*^9, 3.4934647748079505`*^9}}],

Cell[BoxData[
 RowBox[{"eulertobody", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Gamma]", "'"}], "[", "t", "]"}], "}"}], ",", " ", 
     RowBox[{"{", "0", "}"}], ",", " ", 
     RowBox[{"{", "0", "}"}]}], "}"}], " ", "+", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["R", "x"], "[", 
      RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}], "\[Transpose]"}], ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "0", "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Beta]", "'"}], "[", "t", "]"}], "}"}], ",", " ", 
      RowBox[{"{", "0", "}"}]}], "}"}]}], " ", "+", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["R", "y"], "[", 
        RowBox[{"\[Beta]", "[", "t", "]"}], "]"}], ".", 
       RowBox[{
        SubscriptBox["R", "x"], "[", 
        RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}]}], ")"}], "\[Transpose]"}],
     ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "0", "}"}], ",", " ", 
      RowBox[{"{", "0", "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Alpha]", "'"}], "[", "t", "]"}], "}"}]}], 
     "}"}]}]}]}]], "Input",
 CellChangeTimes->{
  3.493464787104654*^9, {3.493464825278837*^9, 3.4934648635200243`*^9}, {
   3.4934649070015116`*^9, 3.493464913301872*^9}, {3.4934657926761694`*^9, 
   3.493465794176255*^9}, {3.493466064924741*^9, 3.4934662946258793`*^9}, 
   3.4934663530342197`*^9, {3.493466479930478*^9, 3.4934664985305414`*^9}, {
   3.4934665600580606`*^9, 3.4934666117790194`*^9}, {3.4934666584346876`*^9, 
   3.4934666801539297`*^9}, {3.4945655783744526`*^9, 
   3.4945655874679728`*^9}, {3.494567839423777*^9, 3.4945678472532253`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Translational motion",
  FontWeight->"Bold"],
 "\n",
 StyleBox["The vehicle motion is given by", "Text"]
}], "Subsubtitle",
 CellChangeTimes->{{3.493468078990939*^9, 3.4934680903105865`*^9}, {
  3.493468122319417*^9, 3.4934681397274127`*^9}}],

Cell[BoxData[
 RowBox[{"quadtrans", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "''"}], "[", "t", "]"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "''"}], "[", "t", "]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"z", "''"}], "[", "t", "]"}], "}"}]}], "}"}], "==", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["R", "z"], "[", 
      RowBox[{"\[Alpha]", "[", "t", "]"}], "]"}], ".", 
     RowBox[{
      SubscriptBox["R", "y"], "[", 
      RowBox[{"\[Beta]", "[", "t", "]"}], "]"}], ".", 
     RowBox[{
      SubscriptBox["R", "x"], "[", 
      RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}], ".", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "0", "}"}], ",", 
       RowBox[{"{", "0", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", "[", "t", "]"}], "}"}]}], "}"}]}], "+", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "0", "}"}], ",", 
      RowBox[{"{", "0", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"-", "g"}], "}"}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.4945605339879303`*^9, 3.4945605750282774`*^9}, {
  3.494560653132745*^9, 3.4945606888127856`*^9}, {3.4945612464146786`*^9, 
  3.4945612740762606`*^9}, {3.4945617188387*^9, 3.494561719203721*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Pendulum\n",
  FontWeight->"Bold"],
 StyleBox["Lagrangian\n", "Subsubtitle",
  FontWeight->"Bold"],
 StyleBox["The Lagrangian is the difference of the kinetic energy and the \
potential energy. To show independency of the pendulum mass, we include is \
(named ", "Subsubtitle"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["m", "p"], ")"}], " ", "in", " ", "this", " ", 
    RowBox[{"derivation", ":"}]}], TraditionalForm]], "None",
  FontSize->16]
}], "Subtitle",
 CellChangeTimes->{{3.493466803975012*^9, 3.493466883895583*^9}, {
   3.493466971975621*^9, 3.493466990905704*^9}, {3.4934730697053914`*^9, 
   3.4934730707844534`*^9}, 3.4945718658520756`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Zeta]", "[", "t", "]"}], "=", 
  SqrtBox[
   RowBox[{
    RowBox[{"L", "^", "2"}], "-", 
    RowBox[{
     RowBox[{"r", "[", "t", "]"}], "^", "2"}], "-", 
    RowBox[{
     RowBox[{"s", "[", "t", "]"}], "^", "2"}]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[ScriptCapitalL]", "[", "t", "]"}], "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], "*", 
    SubscriptBox["m", "p"], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "'"}], "[", "t", "]"}], "+", 
         RowBox[{
          RowBox[{"r", "'"}], "[", "t", "]"}]}], ")"}], "^", "2"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "'"}], "[", "t", "]"}], "+", 
         RowBox[{
          RowBox[{"s", "'"}], "[", "t", "]"}]}], ")"}], "^", "2"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"z", "'"}], "[", "t", "]"}], "+", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"\[Zeta]", "[", "t", "]"}], ",", "t"}], "]"}]}], ")"}], 
       "^", "2"}]}], ")"}]}], "-", 
   RowBox[{
    SubscriptBox["m", "p"], "*", "g", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"z", "[", "t", "]"}], "+", 
      RowBox[{"\[Zeta]", "[", "t", "]"}]}], ")"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.493466894804207*^9, 3.493467093586577*^9}, {
   3.493467389204485*^9, 3.4934673947548027`*^9}, 3.4934730744526625`*^9, {
   3.4945613316075516`*^9, 3.4945613338626804`*^9}}],

Cell[TextData[StyleBox["We take the derivatives as shown in the paper and \
solve for the accelerations r''[t] and s''[t]:",
 FontFamily->"Arial Narrow",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.4934671537510185`*^9, 3.4934671750872383`*^9}}],

Cell[BoxData[{
 RowBox[{"pendulumr", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"\[ScriptCapitalL]", "[", "t", "]"}], ",", " ", 
           RowBox[{
            RowBox[{"r", "'"}], "[", "t", "]"}]}], "]"}], ",", "t"}], "]"}], 
       "-", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"\[ScriptCapitalL]", "[", "t", "]"}], ",", 
         RowBox[{"r", "[", "t", "]"}]}], "]"}]}], "\[Equal]", "0"}], ",", " ", 
     RowBox[{
      RowBox[{"r", "''"}], "[", "t", "]"}]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"pendulums", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"\[ScriptCapitalL]", "[", "t", "]"}], ",", " ", 
           RowBox[{
            RowBox[{"s", "'"}], "[", "t", "]"}]}], "]"}], ",", "t"}], "]"}], 
       "-", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"\[ScriptCapitalL]", "[", "t", "]"}], ",", 
         RowBox[{"s", "[", "t", "]"}]}], "]"}]}], "\[Equal]", "0"}], ",", " ", 
     RowBox[{
      RowBox[{"s", "''"}], "[", "t", "]"}]}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.4934671813105946`*^9, 3.4934672607371373`*^9}, {
  3.4934674438256097`*^9, 3.493467493417446*^9}, {3.494567233477119*^9, 
  3.494567246044838*^9}}],

Cell[TextData[StyleBox["we see that the dynamics on the pendulum depend on \
r[t], s[t], r'[t], s'[t], and the vehicle accelerations x''[t], y''[t], \
z''[t]. We also see that the equations of motion are independent of the \
pendulum mass.",
 FontFamily->"Arial Narrow",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.4934676181515803`*^9, 3.4934676546066656`*^9}, {
  3.493473447624007*^9, 3.493473460031717*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "III. Nominal trajectories\n",
 StyleBox["Constant position",
  FontSize->18]
}], "Title",
 CellChangeTimes->{{3.493467669567521*^9, 3.4934676847663903`*^9}}],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["R", "z"], "[", 
       RowBox[{"\[Alpha]", "[", "t", "]"}], "]"}], ".", 
      RowBox[{
       SubscriptBox["R", "y"], "[", 
       RowBox[{"\[Beta]", "[", "t", "]"}], "]"}], ".", 
      RowBox[{
       SubscriptBox["R", "x"], "[", 
       RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}], ".", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "0", "}"}], ",", 
        RowBox[{"{", "0", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"a", "[", "t", "]"}], "}"}]}], "}"}]}], "+", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "0", "}"}], ",", 
       RowBox[{"{", "0", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"-", "g"}], "}"}]}], "}"}]}], "\[Equal]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "0", "}"}], ",", 
      RowBox[{"{", "0", "}"}], ",", 
      RowBox[{"{", "0", "}"}]}], "}"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Beta]", "[", "t", "]"}], ",", 
     RowBox[{"\[Gamma]", "[", "t", "]"}], ",", 
     RowBox[{"a", "[", "t", "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4934690972811813`*^9, 3.493469139346588*^9}, {
  3.4934691758826776`*^9, 3.493469176601719*^9}, {3.49346937401801*^9, 
  3.4934693814574356`*^9}, {3.4934695430816803`*^9, 3.4934696771863503`*^9}, {
  3.4934697808112774`*^9, 3.493469805074665*^9}, {3.4934698844352045`*^9, 
  3.4934699205102677`*^9}, {3.4945600462390327`*^9, 3.4945600564156146`*^9}, {
  3.4945603447491064`*^9, 3.494560362036095*^9}, {3.4945607972919903`*^9, 
  3.4945607990440903`*^9}, {3.494560895819626*^9, 3.494560966372661*^9}}],

Cell[BoxData[
 RowBox[{"nominalconditionsstanstill", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"\[ScriptCapitalL]", "[", "t", "]"}], ",", " ", 
              RowBox[{
               RowBox[{"r", "'"}], "[", "t", "]"}]}], "]"}], ",", "t"}], 
           "]"}], "-", 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"\[ScriptCapitalL]", "[", "t", "]"}], ",", 
            RowBox[{"r", "[", "t", "]"}]}], "]"}]}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"\[ScriptCapitalL]", "[", "t", "]"}], ",", " ", 
              RowBox[{
               RowBox[{"s", "'"}], "[", "t", "]"}]}], "]"}], ",", "t"}], 
           "]"}], "-", 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"\[ScriptCapitalL]", "[", "t", "]"}], ",", 
            RowBox[{"s", "[", "t", "]"}]}], "]"}]}], "\[Equal]", "0"}]}], 
       "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"x", "''"}], "[", "t", "]"}], "==", "0"}], ",", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "''"}], "[", "t", "]"}], "\[Equal]", "0"}], ",", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"z", "''"}], "[", "t", "]"}], "==", "0"}], ",", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"r", "''"}], "[", "t", "]"}], "\[Equal]", "0"}], ",", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"r", "'"}], "[", "t", "]"}], "\[Equal]", "0"}], ",", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"s", "''"}], "[", "t", "]"}], "\[Equal]", "0"}], ",", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"s", "'"}], "[", "t", "]"}], "\[Equal]", "0"}]}], "}"}]}], 
     "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"r", "[", "t", "]"}], ",", 
      RowBox[{"s", "[", "t", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.494560741742813*^9, 3.4945607860863495`*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["\nCircular trajectory",
 FontSize->18,
 FontWeight->"Bold"]], "Subtitle",
 CellChangeTimes->{{3.4934711016708264`*^9, 3.4934711297604327`*^9}, 
   3.4934729763280506`*^9, {3.4945717915628266`*^9, 3.4945718166022587`*^9}}],

Cell[TextData[StyleBox["We introduce the coordinate transformations on \
translational quadrotor position, translational quadrotor position, and \
quadrotor attitude, as described in the paper:",
 FontFamily->"Arial Narrow",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.494571973202216*^9, 3.494572012850484*^9}}],

Cell[BoxData[{
 RowBox[{"transattquad", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["R", "z"], "[", 
     RowBox[{"\[Alpha]", "[", "t", "]"}], "]"}], ".", 
    RowBox[{
     SubscriptBox["R", "y"], "[", 
     RowBox[{"\[Beta]", "[", "t", "]"}], "]"}], ".", 
    RowBox[{
     SubscriptBox["R", "x"], "[", 
     RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "0", "}"}], ",", 
      RowBox[{"{", "0", "}"}], ",", 
      RowBox[{"{", "1", "}"}]}], "}"}]}], "==", 
   RowBox[{
    RowBox[{
     SubscriptBox["R", "z"], "[", 
     RowBox[{"\[Eta]", "[", "t", "]"}], "]"}], ".", 
    RowBox[{
     SubscriptBox["R", "y"], "[", 
     RowBox[{"\[Mu]", "[", "t", "]"}], "]"}], ".", 
    RowBox[{
     SubscriptBox["R", "x"], "[", 
     RowBox[{"\[Nu]", "[", "t", "]"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "0", "}"}], ",", 
      RowBox[{"{", "0", "}"}], ",", 
      RowBox[{"{", "1", "}"}]}], "}"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"transocquad", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", "[", "t", "]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", "[", "t", "]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", "[", "t", "]"}], "}"}]}], "}"}], "==", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["R", "z"], "[", 
     RowBox[{"\[CapitalOmega]", "*", "t"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"u", "[", "t", "]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"v", "[", "t", "]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"w", "[", "t", "]"}], "}"}]}], 
     "}"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"transocstick", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r", "[", "t", "]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", "[", "t", "]"}], "}"}], ",", 
     RowBox[{"{", "0", "}"}]}], "}"}], "\[Equal]", 
   RowBox[{
    RowBox[{
     SubscriptBox["R", "z"], "[", 
     RowBox[{"\[CapitalOmega]", "*", "t"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p", "[", "t", "]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q", "[", "t", "]"}], "}"}], ",", 
      RowBox[{"{", "0", "}"}]}], "}"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.49347155036549*^9, 3.4934715826273355`*^9}, {
  3.4934716600417633`*^9, 3.4934717492818675`*^9}, {3.4945610213328047`*^9, 
  3.494561035549618*^9}, {3.4945611174793043`*^9, 3.4945612144868526`*^9}}],

Cell[TextData[StyleBox["It is then possible to rewrite the quadrotor equation \
of motion in the rotating coordinate system:",
 FontFamily->"Arial Narrow",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.4945720230420666`*^9, 3.4945720424981794`*^9}}],

Cell[BoxData[
 RowBox[{"quadmotionC", " ", "=", " ", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"Eliminate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FullSimplify", "[", 
          RowBox[{"quadtrans", " ", "/.", " ", 
           RowBox[{"Flatten", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Solve", "[", 
               RowBox[{"transocquad", ",", " ", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"x", "[", "t", "]"}], ",", 
                  RowBox[{"y", "[", "t", "]"}], ",", 
                  RowBox[{"z", "[", "t", "]"}]}], "}"}]}], "]"}], ",", " ", 
              RowBox[{"Solve", "[", 
               RowBox[{
                RowBox[{"D", "[", 
                 RowBox[{"transocquad", ",", "t"}], "]"}], ",", " ", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"x", "'"}], "[", "t", "]"}], ",", " ", 
                  RowBox[{
                   RowBox[{"y", "'"}], "[", "t", "]"}], ",", " ", 
                  RowBox[{
                   RowBox[{"z", "'"}], "[", "t", "]"}]}], "}"}]}], "]"}], ",",
               " ", 
              RowBox[{"Solve", "[", 
               RowBox[{
                RowBox[{"D", "[", 
                 RowBox[{
                  RowBox[{"D", "[", 
                   RowBox[{"transocquad", ",", "t"}], "]"}], ",", "t"}], 
                 "]"}], ",", " ", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"x", "''"}], "[", "t", "]"}], ",", " ", 
                  RowBox[{
                   RowBox[{"y", "''"}], "[", "t", "]"}], ",", " ", 
                  RowBox[{
                   RowBox[{"z", "''"}], "[", "t", "]"}]}], "}"}]}], "]"}]}], 
             " ", "}"}], "]"}]}], "]"}], ",", " ", 
         RowBox[{
          RowBox[{
           RowBox[{
            SubscriptBox["R", "z"], "[", 
            RowBox[{"\[Alpha]", "[", "t", "]"}], "]"}], ".", 
           RowBox[{
            SubscriptBox["R", "y"], "[", 
            RowBox[{"\[Beta]", "[", "t", "]"}], "]"}], ".", 
           RowBox[{
            SubscriptBox["R", "x"], "[", 
            RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}], ".", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", "0", "}"}], ",", 
             RowBox[{"{", "0", "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"a", "[", "t", "]"}], "}"}]}], "}"}]}], "==", 
          RowBox[{
           RowBox[{
            SubscriptBox["R", "z"], "[", 
            RowBox[{"\[CapitalOmega]", "*", "t"}], "]"}], ".", 
           RowBox[{
            SubscriptBox["R", "y"], "[", 
            RowBox[{"\[Mu]", "[", "t", "]"}], "]"}], ".", 
           RowBox[{
            SubscriptBox["R", "x"], "[", 
            RowBox[{"\[Nu]", "[", "t", "]"}], "]"}], ".", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", "0", "}"}], ",", 
             RowBox[{"{", "0", "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"a", "[", "t", "]"}], "}"}]}], "}"}]}]}]}], "}"}], " ", 
       "/.", 
       RowBox[{
        RowBox[{"\[Alpha]", "[", "t", "]"}], "\[Rule]", "0"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Beta]", "[", "t", "]"}], ",", " ", 
        RowBox[{"\[Gamma]", "[", "t", "]"}]}], "}"}]}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"u", "''"}], "[", "t", "]"}], ",", " ", 
      RowBox[{
       RowBox[{"v", "''"}], "[", "t", "]"}], ",", " ", 
      RowBox[{
       RowBox[{"w", "''"}], "[", "t", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.494561377506177*^9, 3.494561561581705*^9}, 
   3.4945616357739487`*^9, {3.494561741901019*^9, 3.4945618009193945`*^9}, {
   3.4945618417417297`*^9, 3.494561974648331*^9}, {3.4945650881144114`*^9, 
   3.4945650920726376`*^9}}],

Cell[TextData[StyleBox["We solve for the nominal states of the quadrotor:",
 FontFamily->"Arial Narrow",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.4945720504186325`*^9, 3.4945720564419765`*^9}}],

Cell[BoxData[
 RowBox[{"nominalquadcircle", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"u", "''"}], "[", "t", "]"}], "\[Equal]", "0"}], ",", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"v", "''"}], "[", "t", "]"}], "\[Equal]", "0"}], ",", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"w", "''"}], "[", "t", "]"}], "\[Equal]", "0"}]}], "}"}], 
        " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"quadmotionC", " ", "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"u", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
            RowBox[{
             RowBox[{
              RowBox[{"v", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
            RowBox[{
             RowBox[{
              RowBox[{"w", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
            RowBox[{
             RowBox[{"u", "[", "t", "]"}], "\[Rule]", "R"}], ",", " ", 
            RowBox[{
             RowBox[{"v", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], 
         "}"}]}], "]"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], ",", " ", 
       RowBox[{"\[Mu]", "[", "t", "]"}], ",", " ", 
       RowBox[{"\[Nu]", "[", "t", "]"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.494562017607788*^9, 3.4945620471394777`*^9}, {
   3.4945620811394224`*^9, 3.494562229612914*^9}, {3.494562272317357*^9, 
   3.4945623148777914`*^9}, {3.494562356798189*^9, 3.494562413692443*^9}, {
   3.4945625765727596`*^9, 3.4945625923556623`*^9}, {3.4945643694283047`*^9, 
   3.4945644257025237`*^9}, {3.4945644903902235`*^9, 3.494564493933426*^9}, 
   3.4945722298788967`*^9}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"notice", " ", "that"}], ",", " ", 
   RowBox[{"in", " ", "the", " ", "paper"}], ",", " ", 
   RowBox[{"we", " ", "have", " ", "chosen", " ", "to", " ", "represent", " ", 
    RowBox[{"\[Mu]", "[", "t", "]"}], " ", "through", " ", "its", " ", 
    "tangent"}], ",", " ", 
   RowBox[{
   "rather", " ", "than", " ", "the", " ", "cosine", " ", "described", " ", 
    RowBox[{"here", ".", " ", "Conversion"}], " ", "is", " ", "possible", " ",
     "through", " ", "simple", " ", "triangular", " ", 
    RowBox[{"identities", "."}]}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.4945645182108145`*^9, 3.4945645432752485`*^9}, {
  3.494564669907491*^9, 3.4945647188992934`*^9}}],

Cell[TextData[StyleBox["and then solve for the control inputs:",
 FontFamily->"Arial Narrow",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.494572061866287*^9, 3.494572066602558*^9}}],

Cell[BoxData[
 RowBox[{"eulerder", " ", "=", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{"transattquad", " ", "/.", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Alpha]", "[", "t", "]"}], "\[Rule]", "0"}], "}"}], ",", 
         " ", 
         RowBox[{"nominalquadcircle", "[", 
          RowBox[{"[", "10", "]"}], "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Eta]", "[", "t", "]"}], "\[Rule]", 
           RowBox[{"\[CapitalOmega]", "*", "t"}]}], "}"}]}], "}"}], "]"}]}], 
     "]"}], ",", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4945656916139297`*^9, 3.4945658908923273`*^9}, {
  3.494565935651888*^9, 3.494566196795824*^9}, {3.49456629235629*^9, 
  3.4945663686116514`*^9}}],

Cell[BoxData[
 RowBox[{"eulerrates", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"eulerder", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", 
        RowBox[{"eulerder", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ",", " ", 
       RowBox[{
        RowBox[{"eulerder", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", 
        RowBox[{"eulerder", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Beta]", "'"}], "[", "t", "]"}], ",", " ", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "t", "]"}]}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.494566373035905*^9, 3.4945664506923466`*^9}, {
  3.4945665380363417`*^9, 3.4945665414195356`*^9}}],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"eulertobody", " ", "/.", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{"eulerrates", ",", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Alpha]", "'"}], "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}],
     "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.494566530959937*^9, 3.4945665854750557`*^9}}],

Cell[TextData[StyleBox["We also rewrite the equations of motion of the \
pendulum in the rotating coordinate system:",
 FontFamily->"Arial Narrow",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.4945720808583736`*^9, 3.4945720903699174`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[ScriptCapitalL]", "c"], "[", "t", "]"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"\[ScriptCapitalL]", "[", "t", "]"}], " ", "/.", 
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{"transocquad", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"x", "[", "t", "]"}], ",", 
           RowBox[{"y", "[", "t", "]"}], ",", 
           RowBox[{"z", "[", "t", "]"}]}], "}"}]}], "]"}], ",", " ", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"transocquad", ",", "t"}], "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"x", "'"}], "[", "t", "]"}], ",", " ", 
           RowBox[{
            RowBox[{"y", "'"}], "[", "t", "]"}], ",", " ", 
           RowBox[{
            RowBox[{"z", "'"}], "[", "t", "]"}]}], "}"}]}], "]"}], ",", " ", 
       RowBox[{"Solve", "[", 
        RowBox[{"transocstick", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"r", "[", "t", "]"}], ",", 
           RowBox[{"s", "[", "t", "]"}]}], "}"}]}], "]"}], ",", " ", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"transocstick", ",", "t"}], "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"r", "'"}], "[", "t", "]"}], ",", " ", 
           RowBox[{
            RowBox[{"s", "'"}], "[", "t", "]"}]}], "}"}]}], "]"}]}], "}"}], 
     "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4934711876247425`*^9, 3.493471238504653*^9}, {
   3.4934713916484118`*^9, 3.493471497810484*^9}, {3.493471578241084*^9, 
   3.4934716369294415`*^9}, {3.493471687210317*^9, 3.493471690633513*^9}, {
   3.4934717562252645`*^9, 3.493471802393905*^9}, {3.493471856780016*^9, 
   3.493471884770617*^9}, {3.4934719392977357`*^9, 3.4934719470191774`*^9}, 
   3.493471988074526*^9, 3.494561324726158*^9}],

Cell[TextData[StyleBox["and get the equilibrium conditions in the rotating \
coordinate system:",
 FontFamily->"Arial Narrow",
 FontSize->16]], "Text",
 CellChangeTimes->{{3.4934731111597624`*^9, 3.4934731319829535`*^9}}],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{
             SubscriptBox["\[ScriptCapitalL]", "c"], "[", "t", "]"}], ",", 
            " ", 
            RowBox[{
             RowBox[{"p", "'"}], "[", "t", "]"}]}], "]"}], ",", "t"}], "]"}], 
        "-", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[ScriptCapitalL]", "c"], "[", "t", "]"}], ",", 
          RowBox[{"p", "[", "t", "]"}]}], "]"}]}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{
             SubscriptBox["\[ScriptCapitalL]", "c"], "[", "t", "]"}], ",", 
            " ", 
            RowBox[{
             RowBox[{"q", "'"}], "[", "t", "]"}]}], "]"}], ",", "t"}], "]"}], 
        "-", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[ScriptCapitalL]", "c"], "[", "t", "]"}], ",", 
          RowBox[{"q", "[", "t", "]"}]}], "]"}]}], "\[Equal]", "0"}]}], "}"}],
     " ", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"p", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"q", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"w", "''"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"u", "''"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"v", "''"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"q", "''"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"p", "''"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"u", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"v", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], "\[Rule]", "R"}], ",", " ", 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], ",", " ", 
   RowBox[{
    SubscriptBox["m", "p"], ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4934719772189045`*^9, 3.4934720184182615`*^9}, {
   3.493472066028984*^9, 3.493472193429271*^9}, 3.493472241217005*^9, {
   3.4934725966313334`*^9, 3.493472612871262*^9}, {3.4934728486297464`*^9, 
   3.4934728557431536`*^9}, {3.493473418463339*^9, 3.493473432348133*^9}, {
   3.493473472877452*^9, 3.493473480636895*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "IV. Dynamics about nominal trajectories\n",
 StyleBox["In this section, we calculate the partial derivatives around the \
setpoint, to demonstrate the derivation of the equations of motion.", "Text",
  FontFamily->"Arial Narrow",
  FontSize->16,
  FontWeight->"Plain"],
 StyleBox["\n",
  FontFamily->"Arial Narrow",
  FontSize->16],
 StyleBox["Constant position",
  FontSize->18]
}], "Title",
 CellChangeTimes->{{3.493473510583608*^9, 3.4934735240073757`*^9}, {
  3.4945610675934505`*^9, 3.494561071153654*^9}, {3.494564752428211*^9, 
  3.4945647633458357`*^9}, {3.494571398340336*^9, 3.4945714298021355`*^9}, {
  3.4945714784439173`*^9, 3.4945714792759647`*^9}}],

Cell[BoxData[
 RowBox[{"nomstateconst", ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"r", "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
    RowBox[{
     RowBox[{"s", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"r", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"s", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], "\[Rule]", "g"}], ",", 
    RowBox[{
     RowBox[{"\[Alpha]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"\[Gamma]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"\[Beta]", "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"z", "''"}], "[", "t", "]"}], "\[Rule]", "0"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.494658539895094*^9, 3.494658549182625*^9}, {
  3.4946585892219152`*^9, 3.494658589645939*^9}}],

Cell[TextData[StyleBox["Quadrotor dynamics",
 FontFamily->"Arial Narrow",
 FontSize->18]], "Text",
 CellChangeTimes->{{3.4945723860908318`*^9, 3.4945723902420692`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Partial", " ", "derivatives", " ", "of", " ", "quadrotor", " ", 
    "translation"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"\"\<motion\>\"", " ", "contains", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x", "''"}], "[", "t", "]"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"y", "''"}], "[", "t", "]"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"z", "''"}], "[", "t", "]"}], "}"}]}], "}"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"motion", ":=", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["R", "z"], "[", 
       RowBox[{"\[Alpha]", "[", "t", "]"}], "]"}], ".", 
      RowBox[{
       SubscriptBox["R", "y"], "[", 
       RowBox[{"\[Beta]", "[", "t", "]"}], "]"}], ".", 
      RowBox[{
       SubscriptBox["R", "x"], "[", 
       RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}], ".", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "0", "}"}], ",", 
        RowBox[{"{", "0", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"a", "[", "t", "]"}], "}"}]}], "}"}]}], "+", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "0", "}"}], ",", 
       RowBox[{"{", "0", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"-", "g"}], "}"}]}], "}"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        OverscriptBox["x", "~"], "''"}], "[", "t", "]"}], ",", 
      RowBox[{
       RowBox[{
        OverscriptBox["y", "~"], "''"}], "[", "t", "]"}], ",", 
      RowBox[{
       RowBox[{
        OverscriptBox["z", "~"], "''"}], "[", "t", "]"}]}], "}"}], "=", 
    "\[IndentingNewLine]", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"motion", ",", 
           RowBox[{"a", "[", "t", "]"}]}], "]"}], "/.", "nomstateconst"}], 
        "}"}], " ", "*", " ", 
       RowBox[{
        OverscriptBox["a", "~"], "[", "t", "]"}]}], " ", "+", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"motion", ",", " ", 
           RowBox[{"\[Alpha]", "[", "t", "]"}]}], "]"}], " ", "/.", 
         "nomstateconst"}], "}"}], " ", "*", " ", 
       RowBox[{
        OverscriptBox["\[Alpha]", "~"], "[", "t", "]"}]}], " ", "+", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"motion", ",", " ", 
           RowBox[{"\[Beta]", "[", "t", "]"}]}], "]"}], " ", "/.", 
         "nomstateconst"}], "}"}], "*", " ", 
       RowBox[{
        OverscriptBox["\[Beta]", "~"], "[", "t", "]"}]}], " ", "+", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"motion", ",", " ", 
           RowBox[{"\[Gamma]", "[", "t", "]"}]}], "]"}], " ", "/.", 
         "nomstateconst"}], "}"}], "*", " ", 
       RowBox[{
        OverscriptBox["\[Gamma]", "~"], "[", "t", "]"}]}]}], " ", 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.4945676015801735`*^9, 3.494567662464656*^9}, {
  3.4945677804554043`*^9, 3.4945678193046265`*^9}, {3.494658645170115*^9, 
  3.4946586569117866`*^9}, {3.494664961145368*^9, 3.4946650520655684`*^9}, {
  3.4946650865625415`*^9, 3.4946651843871365`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Partial", " ", "derivatives", " ", "of", " ", "quadrotor", " ", 
    "rotation"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      OverscriptBox[
       SubscriptBox["\[Omega]", "x"], "~"], "[", "t", "]"}], ",", 
     RowBox[{
      OverscriptBox[
       SubscriptBox["\[Omega]", "y"], "~"], "[", "t", "]"}], ",", 
     RowBox[{
      OverscriptBox[
       SubscriptBox["\[Omega]", "z"], "~"], "[", "t", "]"}]}], "}"}], "=", 
   RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{"eulertobody", ",", " ", 
          RowBox[{
           RowBox[{"\[Alpha]", "'"}], "[", "t", "]"}]}], "]"}], "/.", 
        "nomstateconst"}], "}"}], "*", " ", 
      RowBox[{
       RowBox[{
        OverscriptBox["\[Alpha]", "~"], "'"}], "[", "t", "]"}]}], " ", "+", 
     " ", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{"eulertobody", ",", " ", 
          RowBox[{
           RowBox[{"\[Beta]", "'"}], "[", "t", "]"}]}], "]"}], "/.", 
        "nomstateconst"}], "}"}], "*", " ", 
      RowBox[{
       RowBox[{
        OverscriptBox["\[Beta]", "~"], "'"}], "[", "t", "]"}]}], " ", "+", 
     " ", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{"eulertobody", ",", " ", 
          RowBox[{
           RowBox[{"\[Gamma]", "'"}], "[", "t", "]"}]}], "]"}], "/.", 
        "nomstateconst"}], "}"}], "*", " ", 
      RowBox[{
       RowBox[{
        OverscriptBox["\[Gamma]", "~"], "'"}], "[", "t", "]"}]}]}], "]"}], 
   " "}]}]], "Input",
 CellChangeTimes->{{3.4945676741423235`*^9, 3.494567684146896*^9}, {
  3.4945677151396685`*^9, 3.4945677513497396`*^9}, {3.494571768053482*^9, 
  3.4945717717866955`*^9}, {3.494658661263036*^9, 3.494658667605398*^9}, {
  3.4946651789358253`*^9, 3.494665195958799*^9}, {3.4946654635271025`*^9, 
  3.4946656010159664`*^9}}],

Cell[BoxData[
 StyleBox[
  RowBox[{"Pendulum", " ", "dynamics"}], "Subsubtitle",
  FontSize->16,
  FontWeight->"Plain"]], "Input",
 CellChangeTimes->{{3.494571485499321*^9, 3.4945714877394485`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    OverscriptBox["r", "~"], "''"}], "[", "t", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"r", "''"}], "[", "t", "]"}], " ", "/.", "pendulumr"}], ",",
         " ", 
        RowBox[{"r", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstateconst"}], 
     "]"}], "*", 
    RowBox[{
     OverscriptBox["r", "~"], "[", "t", "]"}]}], "+", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"r", "''"}], "[", "t", "]"}], " ", "/.", "pendulumr"}], ",",
         " ", 
        RowBox[{
         RowBox[{"r", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstateconst"}], "]"}], "*", 
    RowBox[{
     RowBox[{
      OverscriptBox["r", "~"], "'"}], "[", "t", "]"}]}], "+", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"r", "''"}], "[", "t", "]"}], " ", "/.", "pendulumr"}], ",",
         " ", 
        RowBox[{"s", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstateconst"}], 
     "]"}], "*", 
    RowBox[{
     OverscriptBox["s", "~"], "[", "t", "]"}]}], "+", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"r", "''"}], "[", "t", "]"}], " ", "/.", "pendulumr"}], ",",
         " ", 
        RowBox[{
         RowBox[{"s", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstateconst"}], "]"}], "*", 
    RowBox[{
     RowBox[{
      OverscriptBox["s", "~"], "'"}], "[", "t", "]"}]}], "+", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"r", "''"}], "[", "t", "]"}], " ", "/.", "pendulumr"}], ",",
         " ", 
        RowBox[{
         RowBox[{"x", "''"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstateconst"}], "]"}], "*", 
    RowBox[{
     RowBox[{
      OverscriptBox["x", "~"], "''"}], "[", "t", "]"}]}], "+", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"r", "''"}], "[", "t", "]"}], " ", "/.", "pendulumr"}], ",",
         " ", 
        RowBox[{
         RowBox[{"y", "''"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstateconst"}], "]"}], "*", 
    RowBox[{
     RowBox[{
      OverscriptBox["y", "~"], "''"}], "[", "t", "]"}]}], "+", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"r", "''"}], "[", "t", "]"}], " ", "/.", "pendulumr"}], ",",
         " ", 
        RowBox[{
         RowBox[{"z", "''"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstateconst"}], "]"}], "*", 
    RowBox[{
     RowBox[{
      OverscriptBox["z", "~"], "''"}], "[", "t", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.494561287672038*^9, 3.494561289730156*^9}, {
  3.494565125962576*^9, 3.494565127202647*^9}, {3.494565175802427*^9, 
  3.494565214370633*^9}, {3.494565259291202*^9, 3.494565316348466*^9}, {
  3.4945655455575757`*^9, 3.494565552484972*^9}, {3.494567120068632*^9, 
  3.4945671851263533`*^9}, {3.4945672609916925`*^9, 3.494567595310815*^9}, {
  3.494567640995428*^9, 3.4945676424095087`*^9}, {3.4946585960833073`*^9, 
  3.494658617561536*^9}, {3.494664739979718*^9, 3.4946648084026318`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    OverscriptBox["s", "~"], "''"}], "[", "t", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"s", "''"}], "[", "t", "]"}], " ", "/.", "pendulums"}], ",",
         " ", 
        RowBox[{"r", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstateconst"}], 
     "]"}], "*", 
    RowBox[{
     OverscriptBox["r", "~"], "[", "t", "]"}]}], "+", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"s", "''"}], "[", "t", "]"}], " ", "/.", "pendulums"}], ",",
         " ", 
        RowBox[{
         RowBox[{"r", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstateconst"}], "]"}], "*", 
    RowBox[{
     RowBox[{
      OverscriptBox["r", "~"], "'"}], "[", "t", "]"}]}], "+", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"s", "''"}], "[", "t", "]"}], " ", "/.", "pendulums"}], ",",
         " ", 
        RowBox[{"s", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstateconst"}], 
     "]"}], "*", 
    RowBox[{
     OverscriptBox["s", "~"], "[", "t", "]"}]}], "+", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"s", "''"}], "[", "t", "]"}], " ", "/.", "pendulums"}], ",",
         " ", 
        RowBox[{
         RowBox[{"s", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstateconst"}], "]"}], "*", 
    RowBox[{
     RowBox[{
      OverscriptBox["s", "~"], "'"}], "[", "t", "]"}]}], "+", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"s", "''"}], "[", "t", "]"}], " ", "/.", "pendulums"}], ",",
         " ", 
        RowBox[{
         RowBox[{"x", "''"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstateconst"}], "]"}], "*", 
    RowBox[{
     RowBox[{
      OverscriptBox["x", "~"], "''"}], "[", "t", "]"}]}], "+", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"s", "''"}], "[", "t", "]"}], " ", "/.", "pendulums"}], ",",
         " ", 
        RowBox[{
         RowBox[{"y", "''"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstateconst"}], "]"}], "*", 
    RowBox[{
     RowBox[{
      OverscriptBox["y", "~"], "''"}], "[", "t", "]"}]}], "+", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"s", "''"}], "[", "t", "]"}], " ", "/.", "pendulums"}], ",",
         " ", 
        RowBox[{
         RowBox[{"z", "''"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstateconst"}], "]"}], "*", 
    RowBox[{
     RowBox[{
      OverscriptBox["z", "~"], "''"}], "[", "t", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.4945719326328955`*^9, 3.494571934040976*^9}, {
  3.4945722958756714`*^9, 3.4945723010509677`*^9}, {3.4946586212747483`*^9, 
  3.494658634489504*^9}, {3.494664815098015*^9, 3.494664881442809*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Circular trajectory",
 FontWeight->"Bold"]], "Subtitle",
 CellChangeTimes->{{3.4945714573067083`*^9, 3.494571460721904*^9}}],

Cell[BoxData[
 RowBox[{"nomstatecircle", " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", "t", "]"}], "\[Rule]", 
     SubscriptBox["p", "0"]}], ",", " ", 
    RowBox[{
     RowBox[{"q", "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"p", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"q", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"p", "''"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"q", "''"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["p", "0"]}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[CapitalOmega]", "^", "2"}], "+", 
         RowBox[{"g", "/", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"L", "^", "2"}], "-", 
            RowBox[{
             SubscriptBox["p", "0"], "^", "2"}]}], "]"}]}]}], ")"}], "/", 
       RowBox[{"\[CapitalOmega]", "^", "2"}]}]}]}], ",", " ", 
    RowBox[{
     RowBox[{"v", "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"u", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"v", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"w", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"u", "''"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"v", "''"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"w", "''"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], "\[Rule]", 
     SubscriptBox["a", "0"]}], ",", " ", 
    RowBox[{
     RowBox[{"\[Nu]", "[", "t", "]"}], "\[Rule]", "0"}], ",", " ", 
    RowBox[{
     RowBox[{"\[Mu]", "[", "t", "]"}], "\[Rule]", 
     SubscriptBox["\[Mu]", "0"]}]}], "}"}]}]], "Input"],

Cell[TextData[StyleBox["Quadrotor dynamics",
 FontFamily->"Arial Narrow",
 FontSize->18]], "Text",
 CellChangeTimes->{{3.4946602813246975`*^9, 3.494660286306983*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    OverscriptBox["u", "~"], "''"}], "[", "t", "]"}], "=", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"u", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{"u", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}], 
     "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["u", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"u", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{
         RowBox[{"u", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     RowBox[{
      OverscriptBox["u", "~"], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"u", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}], 
     "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["v", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"u", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{
         RowBox[{"v", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     RowBox[{
      OverscriptBox["v", "~"], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"u", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{"w", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}], 
     "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["w", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"u", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{
         RowBox[{"w", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     RowBox[{
      OverscriptBox["w", "~"], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"u", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{"a", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}], 
     "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["a", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"u", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{"\[Mu]", "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["\[Mu]", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"u", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{"\[Nu]", "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["\[Nu]", "~"], "[", "t", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.494568476659225*^9, 3.4945685744898205`*^9}, {
   3.494568613943077*^9, 3.4945687492778177`*^9}, 3.4946583741646147`*^9, {
   3.494658415930003*^9, 3.4946584361951623`*^9}, {3.494659723010764*^9, 
   3.494659783692235*^9}, {3.4946598292208385`*^9, 3.4946599233882246`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    OverscriptBox["v", "~"], "''"}], " ", "[", "t", "]"}], "=", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"v", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{"u", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}], 
     "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["u", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"v", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{
         RowBox[{"u", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     RowBox[{
      OverscriptBox["u", "~"], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"v", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}], 
     "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["v", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"v", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{
         RowBox[{"v", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     RowBox[{
      OverscriptBox["v", "~"], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"v", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{"w", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}], 
     "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["w", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"v", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{
         RowBox[{"w", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     RowBox[{
      OverscriptBox["w", "~"], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"v", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{"a", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}], 
     "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["a", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"v", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{"\[Mu]", "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["\[Mu]", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"v", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{"\[Nu]", "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["\[Nu]", "~"], "[", "t", "]"}], " "}]}]}]], "Input",
 CellChangeTimes->{{3.494568756899254*^9, 3.4945687628755956`*^9}, {
  3.494658441436462*^9, 3.4946584614276056`*^9}, {3.4946596295704193`*^9, 
  3.494659696380241*^9}, {3.49465992785748*^9, 3.4946599725000343`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    OverscriptBox["w", "~"], "''"}], "[", "t", "]"}], "=", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"w", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{"u", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}], 
     "]"}], " ", "*", " ", 
    RowBox[{
     OverscriptBox["u", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"w", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{
         RowBox[{"u", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], " ", "*", " ", 
    RowBox[{
     RowBox[{
      OverscriptBox["u", "~"], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"w", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}], 
     "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["v", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"w", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{
         RowBox[{"v", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     RowBox[{
      OverscriptBox["v", "~"], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"w", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{"w", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}], 
     "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["w", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"w", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{
         RowBox[{"w", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     RowBox[{
      OverscriptBox["w", "~"], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"w", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{"a", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}], 
     "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["a", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"w", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{"\[Mu]", "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["\[Mu]", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"w", "''"}], "[", "t", "]"}], " ", "/.", "quadmotionC"}], 
        ",", " ", 
        RowBox[{"\[Nu]", "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["\[Nu]", "~"], "[", "t", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.4945687785954947`*^9, 3.494568784786849*^9}, {
  3.4946584656038446`*^9, 3.494658484082901*^9}, {3.494659508282482*^9, 
  3.4946596082762012`*^9}, {3.494659977630327*^9, 3.4946600170195804`*^9}}],

Cell[TextData[StyleBox["Pendulum dynamics",
 FontFamily->"Arial Narrow",
 FontSize->18]], "Text",
 CellChangeTimes->{{3.494658518971897*^9, 3.494658521619048*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"pendulump", ":=", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            SubscriptBox["\[ScriptCapitalL]", "c"], "[", "t", "]"}], ",", " ", 
           RowBox[{
            RowBox[{"p", "'"}], "[", "t", "]"}]}], "]"}], ",", "t"}], "]"}], 
       "-", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[ScriptCapitalL]", "c"], "[", "t", "]"}], ",", 
         RowBox[{"p", "[", "t", "]"}]}], "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"p", "''"}], "[", "t", "]"}]}], "]"}]}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"pendulumq", " ", ":=", " ", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[ScriptCapitalL]", "c"], "[", "t", "]"}], ",", " ", 
          RowBox[{
           RowBox[{"q", "'"}], "[", "t", "]"}]}], "]"}], ",", "t"}], "]"}], 
      "-", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[ScriptCapitalL]", "c"], "[", "t", "]"}], ",", 
        RowBox[{"q", "[", "t", "]"}]}], "]"}]}], "\[Equal]", "0"}], ",", " ", 
    RowBox[{
     RowBox[{"q", "''"}], "[", "t", "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.494567926698769*^9, 3.49456798894833*^9}, {
  3.494571700206601*^9, 3.4945717007256308`*^9}, {3.4945722076156235`*^9, 
  3.4945722096617403`*^9}, {3.4945842144933777`*^9, 3.494584361908809*^9}, {
  3.4945864381825657`*^9, 3.4945864401576786`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    OverscriptBox["p", "~"], "''"}], "[", "t", "]"}], "=", 
  RowBox[{"FullSimplify", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"p", "''"}], "[", "t", "]"}], " ", "/.", "pendulump"}], 
         ",", " ", 
         RowBox[{"p", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}],
       "]"}], "*", " ", 
     RowBox[{
      OverscriptBox["p", "~"], "[", "t", "]"}]}], " ", "+", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"p", "''"}], "[", "t", "]"}], " ", "/.", "pendulump"}], 
         ",", " ", 
         RowBox[{
          RowBox[{"p", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
       "nomstatecircle"}], "]"}], "*", " ", 
     RowBox[{
      RowBox[{
       OverscriptBox["p", "~"], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"p", "''"}], "[", "t", "]"}], " ", "/.", "pendulump"}], 
         ",", " ", 
         RowBox[{"q", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}],
       "]"}], "*", " ", 
     RowBox[{
      OverscriptBox["q", "~"], "[", "t", "]"}]}], " ", "+", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"p", "''"}], "[", "t", "]"}], " ", "/.", "pendulump"}], 
         ",", " ", 
         RowBox[{
          RowBox[{"q", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
       "nomstatecircle"}], "]"}], "*", " ", 
     RowBox[{
      RowBox[{
       OverscriptBox["q", "~"], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"p", "''"}], "[", "t", "]"}], " ", "/.", "pendulump"}], 
         ",", " ", 
         RowBox[{"u", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}],
       "]"}], "*", " ", 
     RowBox[{
      OverscriptBox["u", "~"], "[", "t", "]"}]}], " ", "+", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"p", "''"}], "[", "t", "]"}], " ", "/.", "pendulump"}], 
         ",", " ", 
         RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}],
       "]"}], "*", " ", 
     RowBox[{
      OverscriptBox["v", "~"], "[", "t", "]"}]}], " ", "+", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"p", "''"}], "[", "t", "]"}], " ", "/.", "pendulump"}], 
         ",", " ", 
         RowBox[{"w", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}],
       "]"}], "*", " ", 
     RowBox[{
      OverscriptBox["w", "~"], "[", "t", "]"}]}], " ", "+", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"p", "''"}], "[", "t", "]"}], " ", "/.", "pendulump"}], 
         ",", " ", 
         RowBox[{
          RowBox[{"u", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
       "nomstatecircle"}], "]"}], "*", " ", 
     RowBox[{
      RowBox[{
       OverscriptBox["u", "~"], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"p", "''"}], "[", "t", "]"}], " ", "/.", "pendulump"}], 
         ",", " ", 
         RowBox[{
          RowBox[{"v", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
       "nomstatecircle"}], "]"}], "*", " ", 
     RowBox[{
      RowBox[{
       OverscriptBox["v", "~"], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"p", "''"}], "[", "t", "]"}], " ", "/.", "pendulump"}], 
         ",", " ", 
         RowBox[{
          RowBox[{"w", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
       "nomstatecircle"}], "]"}], "*", " ", 
     RowBox[{
      RowBox[{
       OverscriptBox["w", "~"], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"p", "''"}], "[", "t", "]"}], " ", "/.", "pendulump"}], 
         ",", " ", 
         RowBox[{
          RowBox[{"u", "''"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
       "nomstatecircle"}], "]"}], "*", " ", 
     RowBox[{
      RowBox[{
       OverscriptBox["u", "~"], "''"}], "[", "t", "]"}]}], " ", "+", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"p", "''"}], "[", "t", "]"}], " ", "/.", "pendulump"}], 
         ",", " ", 
         RowBox[{
          RowBox[{"v", "''"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
       "nomstatecircle"}], "]"}], "*", " ", 
     RowBox[{
      RowBox[{
       OverscriptBox["v", "~"], "''"}], "[", "t", "]"}]}], " ", "+", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"p", "''"}], "[", "t", "]"}], " ", "/.", "pendulump"}], 
         ",", " ", 
         RowBox[{
          RowBox[{"w", "''"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
       "nomstatecircle"}], "]"}], "*", " ", 
     RowBox[{
      RowBox[{
       OverscriptBox["w", "~"], "''"}], "[", "t", "]"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "this", " ", "can", " ", "be", " ", "put", " ", "in", " ", "the", " ", 
      "form", " ", "shown", " ", "in", " ", "the", " ", "paper", " ", "using",
       " ", "1"}], "-", 
     RowBox[{
      RowBox[{
       SubscriptBox["p", "0"], "^", "2"}], "/", 
      SuperscriptBox["L", "2"]}]}], "\[Equal]", 
    RowBox[{
     SuperscriptBox["\[Zeta]", "2"], "/", 
     RowBox[{"L", "^", "2"}]}]}], "*)"}]}]}], "Input",
 CellChangeTimes->{{3.4945854416965694`*^9, 3.4945854419625845`*^9}, {
   3.4946577952385015`*^9, 3.4946579621130466`*^9}, 3.494658075606538*^9, 
   3.49465825642288*^9, {3.494658307870823*^9, 3.494658359174757*^9}, {
   3.4946600363776875`*^9, 3.494660156944584*^9}, {3.494660359075145*^9, 
   3.4946603896308928`*^9}, {3.494660427227043*^9, 3.494660461816021*^9}, {
   3.494660591795456*^9, 3.494660597433778*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    OverscriptBox["q", "~"], "''"}], "[", "t", "]"}], "=", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"q", "''"}], "[", "t", "]"}], " ", "/.", "pendulumq"}], ",",
         " ", 
        RowBox[{"p", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}], 
     "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["p", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"q", "''"}], "[", "t", "]"}], " ", "/.", "pendulumq"}], ",",
         " ", 
        RowBox[{
         RowBox[{"p", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     RowBox[{
      OverscriptBox["p", "~"], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"q", "''"}], "[", "t", "]"}], " ", "/.", "pendulumq"}], ",",
         " ", 
        RowBox[{"q", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}], 
     "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["q", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"q", "''"}], "[", "t", "]"}], " ", "/.", "pendulumq"}], ",",
         " ", 
        RowBox[{
         RowBox[{"q", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     RowBox[{
      OverscriptBox["q", "~"], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"q", "''"}], "[", "t", "]"}], " ", "/.", "pendulumq"}], ",",
         " ", 
        RowBox[{"u", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}], 
     "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["u", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"q", "''"}], "[", "t", "]"}], " ", "/.", "pendulumq"}], ",",
         " ", 
        RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}], 
     "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["v", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"q", "''"}], "[", "t", "]"}], " ", "/.", "pendulumq"}], ",",
         " ", 
        RowBox[{"w", "[", "t", "]"}]}], "]"}], " ", "/.", "nomstatecircle"}], 
     "]"}], "*", " ", 
    RowBox[{
     OverscriptBox["w", "~"], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"q", "''"}], "[", "t", "]"}], " ", "/.", "pendulumq"}], ",",
         " ", 
        RowBox[{
         RowBox[{"u", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     RowBox[{
      OverscriptBox["u", "~"], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"q", "''"}], "[", "t", "]"}], " ", "/.", "pendulumq"}], ",",
         " ", 
        RowBox[{
         RowBox[{"v", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     RowBox[{
      OverscriptBox["v", "~"], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"q", "''"}], "[", "t", "]"}], " ", "/.", "pendulumq"}], ",",
         " ", 
        RowBox[{
         RowBox[{"w", "'"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     RowBox[{
      OverscriptBox["w", "~"], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"q", "''"}], "[", "t", "]"}], " ", "/.", "pendulumq"}], ",",
         " ", 
        RowBox[{
         RowBox[{"u", "''"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     RowBox[{
      OverscriptBox["u", "~"], "''"}], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"q", "''"}], "[", "t", "]"}], " ", "/.", "pendulumq"}], ",",
         " ", 
        RowBox[{
         RowBox[{"v", "''"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     RowBox[{
      OverscriptBox["v", "~"], "''"}], "[", "t", "]"}]}], " ", "+", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"q", "''"}], "[", "t", "]"}], " ", "/.", "pendulumq"}], ",",
         " ", 
        RowBox[{
         RowBox[{"w", "''"}], "[", "t", "]"}]}], "]"}], " ", "/.", 
      "nomstatecircle"}], "]"}], "*", " ", 
    RowBox[{
     RowBox[{
      OverscriptBox["w", "~"], "''"}], "[", "t", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.4945697871301794`*^9, 3.4945698030420895`*^9}, {
  3.4945698503857975`*^9, 3.4945698529539447`*^9}, {3.4945699341045856`*^9, 
  3.494569947045326*^9}, {3.494658111333581*^9, 3.4946581137037168`*^9}, {
  3.4946582063000135`*^9, 3.49465825274967*^9}, {3.4946601632359433`*^9, 
  3.494660253479105*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1602, 955},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Text"]]}, Visible -> False, FrontEndVersion -> 
  "7.0 for Microsoft Windows (64-bit) (February 18, 2009)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 74, 1, 31, "Input"],
Cell[CellGroupData[{
Cell[644, 25, 600, 13, 171, "Title"],
Cell[1247, 40, 1885, 53, 72, "Input"],
Cell[CellGroupData[{
Cell[3157, 97, 502, 11, 48, "Subsubtitle"],
Cell[3662, 110, 1751, 48, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5450, 163, 269, 7, 50, "Subsubtitle"],
Cell[5722, 172, 1311, 39, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7070, 216, 710, 18, 94, "Subtitle"],
Cell[7783, 236, 1576, 49, 69, "Input"],
Cell[9362, 287, 248, 4, 34, "Text"],
Cell[9613, 293, 1537, 44, 52, "Input"],
Cell[11153, 339, 414, 7, 34, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11616, 352, 175, 5, 115, "Title"],
Cell[11794, 359, 1672, 43, 31, "Input"],
Cell[13469, 404, 2286, 65, 52, "Input"],
Cell[CellGroupData[{
Cell[15780, 473, 245, 4, 65, "Subtitle"],
Cell[16028, 479, 315, 5, 34, "Text"],
Cell[16346, 486, 2535, 78, 72, "Input"],
Cell[18884, 566, 250, 4, 34, "Text"],
Cell[19137, 572, 3942, 101, 92, "Input"],
Cell[23082, 675, 199, 3, 34, "Text"],
Cell[23284, 680, 1946, 48, 31, "Input"],
Cell[25233, 730, 723, 14, 52, "Input"],
Cell[25959, 746, 184, 3, 34, "Text"],
Cell[26146, 751, 851, 22, 31, "Input"],
Cell[27000, 775, 1006, 29, 31, "Input"],
Cell[28009, 806, 374, 10, 31, "Input"],
Cell[28386, 818, 242, 4, 34, "Text"],
Cell[28631, 824, 2026, 51, 31, "Input"],
Cell[30660, 877, 221, 4, 34, "Text"],
Cell[30884, 883, 2825, 80, 52, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[33758, 969, 681, 16, 138, "Title"],
Cell[34442, 987, 960, 27, 31, "Input"],
Cell[35405, 1016, 168, 3, 36, "Text"],
Cell[35576, 1021, 3488, 103, 179, "Input"],
Cell[39067, 1126, 2089, 60, 117, "Input"],
Cell[41159, 1188, 198, 5, 33, "Input"],
Cell[41360, 1195, 3793, 117, 152, "Input"],
Cell[45156, 1314, 3501, 113, 152, "Input"],
Cell[CellGroupData[{
Cell[48682, 1431, 148, 2, 51, "Subtitle"],
Cell[48833, 1435, 2156, 64, 52, "Input"],
Cell[50992, 1501, 166, 3, 36, "Text"],
Cell[51161, 1506, 4523, 141, 212, "Input"],
Cell[55687, 1649, 4454, 140, 212, "Input"],
Cell[60144, 1791, 4455, 140, 212, "Input"],
Cell[64602, 1933, 163, 3, 36, "Text"],
Cell[64768, 1938, 1687, 48, 52, "Input"],
Cell[66458, 1988, 7345, 225, 318, "Input"],
Cell[73806, 2215, 6508, 208, 292, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
